.. _ufile:

UFile Class
###########

.. autoclass:: urgap.ufile.ufile.UFile
   :members:

   .. automethod:: __init__
   .. automethod:: __repr__
   .. automethod:: __eq__
   .. automethod:: __lt__
   .. automethod:: __deepcopy__

UUriDict Class
##############

.. autoclass:: urgap.ufile.uuri.UUri
   :members:

   .. automethod:: __init__

UFile IO Classes
################

.. autoclass:: urgap.ufile.io._base.UIOBase
   :members:

   .. automethod:: __init__

.. autoclass:: urgap.ufile.io.azure_blob.IOAzureBlobStorage
   :members:

   .. automethod:: __init__

.. autoclass:: urgap.ufile.io.file.IOPython
   :members:

   .. automethod:: __init__

.. autoclass:: urgap.ufile.io.google_storage.IOGoogleCloudStorage
   :members:

   .. automethod:: __init__

.. autoclass:: urgap.ufile.io.https.IOHTTPS
   :members:

   .. automethod:: __init__

.. autoclass:: urgap.ufile.io.libcloud.IOLibcloud
   :members:

   .. automethod:: __init__

.. autoclass:: urgap.ufile.io.mylabdata.IOMyLabData
   :members:

   .. automethod:: __init__
